//---------------------------------------------------------------------------
//Header Includes
//---------------------------------------------------------------------------
#include "AbstractCommand.h"
#include "xmlparse.h"

/**
   DeleteElementCommand encapsulates the deletion of an element to the document.
   It is constructed using the current node and upon excecution 
   it deletes the node from the document, even if another view has changed the current node
   to another value.In this sense, it is the opposite of AddElementCommand

   @see AddElementCommand
 */

class DeleteElementCommand : AbstractCommand 
{
 public:
  /**@name Overriden Do / Undo methods
   */
  //@{
  
  /** The call to do() will generate the deletion of target (the current node
   * at the time of the creation of the object) from the document.
   * @return a deep Notification object saying that parent has changed.
   * @see Notification.h
   */
  Notification do();

  /** The call to undo() will generate the reinsertion of target as child of 
   *  its parent (the parent of the current node at the time of the creation
   *  of the object).
   * @return a deep Notification object saying that parent has changed.
   * @see Notification.h
   */
  Notification void undo();
  //@}

  /** @name Get methods
   *
   */
  //@{
  /** Returns the description of the operation
   * (Actually the string \"Delete Element %s\" where %s is the name of the element being deleted)
   */
  string getDescription();

  /// gets the parent
  const xmlNode *getParent();

  /// gets the target
  const xmlNode *getTarget();
  //@}

  /** @name Set methods
   *
   */
  //@{
  /// Note that there is no set parent nor target, since they are consts set upon creation
  //@}

 private:

  /// the current node at the time of the creation of the object
  const xmlNode *parent;

  /// the node to be inserted as child of parent 
  const xmlNode *target;
};








