//---------------------------------------------------------------------------
//Header Includes
//---------------------------------------------------------------------------
#ifndef Notification_H
#define Notification_H


//---------------------------------------------------------------------------
//Constants
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
// Class definition
//---------------------------------------------------------------------------

/**
   Notification objects are a simple, yet fundamental part of the controller-view
   interaction. A Notification object encapsulates the change inflicted in the 
   model by a command. 
   It includes the node where the change was made(affected)
   and a node, containing the exact state that affected has now on the model: If
   the children of affected change on the model because of the change on it (e.g
   a DeleteElement) the Notification is said to express a *deep* change;
   otherwise(e.g. an AddAttribute) it is a *shallow* change.
   This mechanism is devised so smart views can efficiently update themselves, 
   instead of redrawing the whole document.

   @see
*/
class Notification {
  public:
   /**@name Get/is Methods
    * Note that there are not set Methods. This is an immutable object
   */
   //@{
  /** 
      Indicates whether the change is deep or not.
      @return is the change deep? 
   */
  int isDeep();

   /** 
      Return the affected Node.
      @return the affected node (usually for lookup in a hash)
   */
  const xmlNode* getAffected();

   /** 
      Return the newState Node.
      @return the newState node (usually for replacement in the view)
   */
  const xmlNode* getNewState();
  //@}

  /**@name Constructors
  *
  */
  //@{
  /**
     This simple constructor just sets the values for the three parameters 
     on a notification.
  */
  Notification(xmlNode *newAffected,xmlNode *newState,int newDeep);
  //@}
 protected:
 private:
  /// Affected node
  xmlNode *affected;
  /// The new state of the affected node
  xmlNode *state;
  /// Indicates whether the change is deep
  int deep;
};
#endif
